summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commitb6edfe41c9395f2e20784cbf0e630af6426950a3 (patch)
tree56ed9b871d4296e6c15949c24e16420be1b28697 /kexi/3rdparty/kexisql
parentef39e8e4178a8f98cf5f154916ba0f03e4855206 (diff)
downloadkoffice-b6edfe41c9395f2e20784cbf0e630af6426950a3.tar.gz
koffice-b6edfe41c9395f2e20784cbf0e630af6426950a3.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/3rdparty/kexisql')
-rw-r--r--kexi/3rdparty/kexisql/src/btree.c4
-rw-r--r--kexi/3rdparty/kexisql/src/btree_rb.c2
-rw-r--r--kexi/3rdparty/kexisql/src/encode.c6
-rw-r--r--kexi/3rdparty/kexisql/src/insert.c2
-rw-r--r--kexi/3rdparty/kexisql/src/os.c2
-rw-r--r--kexi/3rdparty/kexisql/src/pager.c2
-rw-r--r--kexi/3rdparty/kexisql/src/select.c2
-rw-r--r--kexi/3rdparty/kexisql/src/sqlite.h2
-rw-r--r--kexi/3rdparty/kexisql/src/tclsqlite.c2
-rw-r--r--kexi/3rdparty/kexisql/src/vdbe.c6
-rw-r--r--kexi/3rdparty/kexisql/src/vdbeInt.h2
-rw-r--r--kexi/3rdparty/kexisql/src/where.c2
-rw-r--r--kexi/3rdparty/kexisql/tool/lemon.c30
-rw-r--r--kexi/3rdparty/kexisql/tool/lempar.c2
14 files changed, 33 insertions, 33 deletions
diff --git a/kexi/3rdparty/kexisql/src/btree.c b/kexi/3rdparty/kexisql/src/btree.c
index 3a79a6240..a257011ed 100644
--- a/kexi/3rdparty/kexisql/src/btree.c
+++ b/kexi/3rdparty/kexisql/src/btree.c
@@ -47,7 +47,7 @@
** the file really is a valid BTree database, a pointer to a list of unused
** pages in the file, and some meta information. The root of the first
** BTree begins on page 2 of the file. (Pages are numbered beginning with
-** 1, not 0.) Thus a minimum database tqcontains 2 pages.
+** 1, not 0.) Thus a minimum database contains 2 pages.
*/
#include "sqliteInt.h"
#include "pager.h"
@@ -128,7 +128,7 @@ static const char zMagicHeader[] =
/*
** The first page of the database file contains a magic header string
-** to identify the file as an SQLite database file. It also tqcontains
+** to identify the file as an SQLite database file. It also contains
** a pointer to the first free page of the file. Page 2 contains the
** root of the principle BTree. The file might contain other BTrees
** rooted on pages above 2.
diff --git a/kexi/3rdparty/kexisql/src/btree_rb.c b/kexi/3rdparty/kexisql/src/btree_rb.c
index 8d905ef0b..afb2c5084 100644
--- a/kexi/3rdparty/kexisql/src/btree_rb.c
+++ b/kexi/3rdparty/kexisql/src/btree_rb.c
@@ -768,7 +768,7 @@ static int memRbtreeInsert(
memcpy(pData, pDataInput, nData);
/* Move the cursor to a node near the key to be inserted. If the key already
- * exists in the table, then (match == 0). In this case we can just tqreplace
+ * exists in the table, then (match == 0). In this case we can just replace
* the data associated with the entry, we don't need to manipulate the tree.
*
* If there is no exact match, then the cursor points at what would be either
diff --git a/kexi/3rdparty/kexisql/src/insert.c b/kexi/3rdparty/kexisql/src/insert.c
index 8c303573a..e8d5e567c 100644
--- a/kexi/3rdparty/kexisql/src/insert.c
+++ b/kexi/3rdparty/kexisql/src/insert.c
@@ -541,7 +541,7 @@ insert_cleanup:
/*
** Generate code to do a constraint check prior to an INSERT or an UPDATE.
**
-** When this routine is called, the stack tqcontains (from bottom to top)
+** When this routine is called, the stack contains (from bottom to top)
** the following values:
**
** 1. The recno of the row to be updated before the update. This
diff --git a/kexi/3rdparty/kexisql/src/os.c b/kexi/3rdparty/kexisql/src/os.c
index fc0f91e2d..79eb15e5b 100644
--- a/kexi/3rdparty/kexisql/src/os.c
+++ b/kexi/3rdparty/kexisql/src/os.c
@@ -172,7 +172,7 @@ static unsigned int elapse;
**
** If you close a file descriptor that points to a file that has locks,
** all locks on that file that are owned by the current process are
-** released. To work around this problem, each OsFile structure tqcontains
+** released. To work around this problem, each OsFile structure contains
** a pointer to an openCnt structure. There is one openCnt structure
** per open inode, which means that multiple OsFiles can point to a single
** openCnt. When an attempt is made to close an OsFile, if there are
diff --git a/kexi/3rdparty/kexisql/src/pager.c b/kexi/3rdparty/kexisql/src/pager.c
index 566c778c3..0ce24086e 100644
--- a/kexi/3rdparty/kexisql/src/pager.c
+++ b/kexi/3rdparty/kexisql/src/pager.c
@@ -1920,7 +1920,7 @@ int sqlitepager_overwrite(Pager *pPager, Pgno pgno, void *pData){
** a transaction then removed from the freelist during a later part
** of the same transaction and reused for some other purpose. When it
** is first added to the freelist, this routine is called. When reused,
-** the dont_rollback() routine is called. But because the page tqcontains
+** the dont_rollback() routine is called. But because the page contains
** critical data, we still need to be sure it gets rolled back in spite
** of the dont_rollback() call.
*/
diff --git a/kexi/3rdparty/kexisql/src/select.c b/kexi/3rdparty/kexisql/src/select.c
index 28136e76e..0dde6d2e4 100644
--- a/kexi/3rdparty/kexisql/src/select.c
+++ b/kexi/3rdparty/kexisql/src/select.c
@@ -1707,7 +1707,7 @@ static int flattenSubquery(
** the FROM clause of the outer query. Before doing this, remember
** the cursor number for the original outer query FROM element in
** iParent. The iParent cursor will never be used. Subsequent code
- ** will scan expressions looking for iParent references and tqreplace
+ ** will scan expressions looking for iParent references and replace
** those references with expressions that resolve to the subquery FROM
** elements we are now copying in.
*/
diff --git a/kexi/3rdparty/kexisql/src/sqlite.h b/kexi/3rdparty/kexisql/src/sqlite.h
index 4264cc1b0..dd227cd00 100644
--- a/kexi/3rdparty/kexisql/src/sqlite.h
+++ b/kexi/3rdparty/kexisql/src/sqlite.h
@@ -828,7 +828,7 @@ int sqlite_rekey(
);
/*
-** Encode a binary buffer "in" of size n bytes so that it tqcontains
+** Encode a binary buffer "in" of size n bytes so that it contains
** no instances of characters '\'' or '\000'. The output is
** null-terminated and can be used as a string value in an INSERT
** or UPDATE statement. Use sqlite_decode_binary() to convert the
diff --git a/kexi/3rdparty/kexisql/src/tclsqlite.c b/kexi/3rdparty/kexisql/src/tclsqlite.c
index 7256eafeb..fdc2f5e88 100644
--- a/kexi/3rdparty/kexisql/src/tclsqlite.c
+++ b/kexi/3rdparty/kexisql/src/tclsqlite.c
@@ -999,7 +999,7 @@ static int DbObjCmd(void *cd, Tcl_Interp *interp, int objc,Tcl_Obj *const*objv){
** DBNAME that is used to control that connection. The database
** connection is deleted when the DBNAME command is deleted.
**
-** The second argument is the name of the directory that tqcontains
+** The second argument is the name of the directory that contains
** the sqlite database that is to be accessed.
**
** For testing purposes, we also support the following:
diff --git a/kexi/3rdparty/kexisql/src/vdbe.c b/kexi/3rdparty/kexisql/src/vdbe.c
index 6ac810587..9f31e9cf6 100644
--- a/kexi/3rdparty/kexisql/src/vdbe.c
+++ b/kexi/3rdparty/kexisql/src/vdbe.c
@@ -233,7 +233,7 @@ static int hardDynamicify(Mem *pStack){
}
/*
-** An ephemeral string value (signified by the MEM_Ephem flag) tqcontains
+** An ephemeral string value (signified by the MEM_Ephem flag) contains
** a pointer to a dynamically allocated string where some other entity
** is responsible for deallocating that string. Because the stack entry
** does not control the string, it might be deleted without the stack
@@ -4151,8 +4151,8 @@ case OP_FileOpen: {
** Read a single line of input from the open file (the file opened using
** FileOpen). If we reach end-of-file, jump immediately to P2. If
** we are able to get another line, split the line apart using P3 as
-** a delimiter. There should be P1 fields. If the input line tqcontains
-** more than P1 fields, ignore the excess. If the input line tqcontains
+** a delimiter. There should be P1 fields. If the input line contains
+** more than P1 fields, ignore the excess. If the input line contains
** fewer than P1 fields, assume the remaining fields contain NULLs.
**
** Input ends if a line consists of just "\.". A field containing only
diff --git a/kexi/3rdparty/kexisql/src/vdbeInt.h b/kexi/3rdparty/kexisql/src/vdbeInt.h
index 3daa74c3b..79b6b51a5 100644
--- a/kexi/3rdparty/kexisql/src/vdbeInt.h
+++ b/kexi/3rdparty/kexisql/src/vdbeInt.h
@@ -161,7 +161,7 @@ struct sqlite_func {
/*
** An Agg structure describes an Aggregator. Each Agg consists of
-** zero or more Aggregator elements (AggElem). Each AggElem tqcontains
+** zero or more Aggregator elements (AggElem). Each AggElem contains
** a key and one or more values. The values are used in processing
** aggregate functions in a SELECT. The key is used to implement
** the GROUP BY clause of a select.
diff --git a/kexi/3rdparty/kexisql/src/where.c b/kexi/3rdparty/kexisql/src/where.c
index 58b6e3d0d..bb6a7f4f6 100644
--- a/kexi/3rdparty/kexisql/src/where.c
+++ b/kexi/3rdparty/kexisql/src/where.c
@@ -302,7 +302,7 @@ static void disableTerm(WhereLevel *pLevel, Expr **ppExpr){
/*
** Generate the beginning of the loop used for WHERE clause processing.
-** The return value is a pointer to an (opaque) structure that tqcontains
+** The return value is a pointer to an (opaque) structure that contains
** information needed to terminate the loop. Later, the calling routine
** should invoke sqliteWhereEnd() with the return value of this function
** in order to complete the WHERE clause processing.
diff --git a/kexi/3rdparty/kexisql/tool/lemon.c b/kexi/3rdparty/kexisql/tool/lemon.c
index 84f73d170..a0eef8104 100644
--- a/kexi/3rdparty/kexisql/tool/lemon.c
+++ b/kexi/3rdparty/kexisql/tool/lemon.c
@@ -298,7 +298,7 @@ char *Strsafe();
void Strsafe_init(/* void */);
int Strsafe_insert(/* char * */);
-char *Strsafe_tqfind(/* char * */);
+char *Strsafe_find(/* char * */);
/* Routines for handling symbols of the grammar */
@@ -306,7 +306,7 @@ struct symbol *Symbol_new();
int Symbolcmpp(/* struct symbol **, struct symbol ** */);
void Symbol_init(/* void */);
int Symbol_insert(/* struct symbol *, char * */);
-struct symbol *Symbol_tqfind(/* char * */);
+struct symbol *Symbol_find(/* char * */);
struct symbol *Symbol_Nth(/* int */);
int Symbol_count(/* */);
struct symbol **Symbol_arrayof(/* */);
@@ -317,14 +317,14 @@ int Configcmp(/* struct config *, struct config * */);
struct state *State_new();
void State_init(/* void */);
int State_insert(/* struct state *, struct config * */);
-struct state *State_tqfind(/* struct config * */);
+struct state *State_find(/* struct config * */);
struct state **State_arrayof(/* */);
/* Routines used for efficiency in Configlist_add */
void Configtable_init(/* void */);
int Configtable_insert(/* struct config * */);
-struct config *Configtable_tqfind(/* struct config * */);
+struct config *Configtable_find(/* struct config * */);
void Configtable_clear(/* int(*)(struct config *) */);
/****************** From the file "action.c" *******************************/
/*
@@ -510,7 +510,7 @@ struct lemon *lemp;
/* Find the start symbol */
if( lemp->start ){
- sp = Symbol_tqfind(lemp->start);
+ sp = Symbol_find(lemp->start);
if( sp==0 ){
ErrorMsg(lemp->filename,0,
"The specified start symbol \"%s\" is not \
@@ -571,7 +571,7 @@ struct lemon *lemp;
bp = Configlist_basis();
/* Get a state with the same basis */
- stp = State_tqfind(bp);
+ stp = State_find(bp);
if( stp ){
/* A state with the same basis already exists! Copy all the follow-set
** propagation links from the state under construction into the
@@ -755,7 +755,7 @@ struct lemon *lemp;
/* Add the accepting token */
if( lemp->start ){
- sp = Symbol_tqfind(lemp->start);
+ sp = Symbol_find(lemp->start);
if( sp==0 ) sp = lemp->rule->lhs;
}else{
sp = lemp->rule->lhs;
@@ -933,7 +933,7 @@ int dot; /* Index into the RHS of the rule where the dot goes */
assert( currentend!=0 );
model.rp = rp;
model.dot = dot;
- cfp = Configtable_tqfind(&model);
+ cfp = Configtable_find(&model);
if( cfp==0 ){
cfp = newconfig();
cfp->rp = rp;
@@ -961,7 +961,7 @@ int dot;
assert( currentend!=0 );
model.rp = rp;
model.dot = dot;
- cfp = Configtable_tqfind(&model);
+ cfp = Configtable_find(&model);
if( cfp==0 ){
cfp = newconfig();
cfp->rp = rp;
@@ -3470,7 +3470,7 @@ char *y;
{
char *z;
- z = Strsafe_tqfind(y);
+ z = Strsafe_find(y);
if( z==0 && (z=malloc( strlen(y)+1 ))!=0 ){
strcpy(z,y);
Strsafe_insert(z);
@@ -3581,7 +3581,7 @@ char *data;
/* Return a pointer to data assigned to the given key. Return NULL
** if no such key. */
-char *Strsafe_tqfind(key)
+char *Strsafe_find(key)
char *key;
{
int h;
@@ -3605,7 +3605,7 @@ char *x;
{
struct symbol *sp;
- sp = Symbol_tqfind(x);
+ sp = Symbol_find(x);
if( sp==0 ){
sp = (struct symbol *)malloc( sizeof(struct symbol) );
MemoryCheck(sp);
@@ -3738,7 +3738,7 @@ char *key;
/* Return a pointer to data assigned to the given key. Return NULL
** if no such key. */
-struct symbol *Symbol_tqfind(key)
+struct symbol *Symbol_find(key)
char *key;
{
int h;
@@ -3944,7 +3944,7 @@ struct config *key;
/* Return a pointer to data assigned to the given key. Return NULL
** if no such key. */
-struct state *State_tqfind(key)
+struct state *State_find(key)
struct config *key;
{
int h;
@@ -4087,7 +4087,7 @@ struct config *data;
/* Return a pointer to data assigned to the given key. Return NULL
** if no such key. */
-struct config *Configtable_tqfind(key)
+struct config *Configtable_find(key)
struct config *key;
{
int h;
diff --git a/kexi/3rdparty/kexisql/tool/lempar.c b/kexi/3rdparty/kexisql/tool/lempar.c
index b6ffceb0d..5604fe10d 100644
--- a/kexi/3rdparty/kexisql/tool/lempar.c
+++ b/kexi/3rdparty/kexisql/tool/lempar.c
@@ -58,7 +58,7 @@
#define YY_NO_ACTION (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION (YYNSTATE+YYNRULE)
-/* Next is the action table. Each entry in this table tqcontains
+/* Next is the action table. Each entry in this table contains
**
** + An integer which is the number representing the look-ahead
** token
diff --git a/kexi/3rdparty/kexisql/src/encode.c b/kexi/3rdparty/kexisql/src/encode.c
index 3e14e641b..899901b52 100644
--- a/kexi/3rdparty/kexisql/src/encode.c
+++ b/kexi/3rdparty/kexisql/src/encode.c
@@ -67,7 +67,7 @@
** (2) Copy each input character into the output buffer, one by
** one, adding the offset value as you copy.
**
-** (3) If the value of an input character plus offset is 0x00, tqreplace
+** (3) If the value of an input character plus offset is 0x00, replace
** that one character by the two-character sequence 0x01 0x01.
** If the sum is 0x01, replace it with 0x01 0x02. If the sum
** is 0x27, replace it with 0x01 0x03.
@@ -101,7 +101,7 @@
*/
/*
** Encode a binary buffer "in" of size n bytes so that it tqcontains
** no instances of characters '\'' or '\000'. The output is
** null-terminated and can be used as a string value in an INSERT
** or UPDATE statement. Use sqlite_decode_binary() to convert the
@@ -231,7 +231,7 @@ int main(int argc, char **argv){
}
for(j=0; out[j]; j++){
if( out[j]=='\'' ){
- printf(" ERROR tqcontains (')\n");
+ printf(" ERROR contains (')\n");
exit(1);
}
}
@@ -101,7 +101,7 @@
*/
/*
-** Encode a binary buffer "in" of size n bytes so that it tqcontains
+** Encode a binary buffer "in" of size n bytes so that it contains
** no instances of characters '\'' or '\000'. The output is
** null-terminated and can be used as a string value in an INSERT